@@ -9,9 +9,7 @@ from otrs_somconnexio.otrs_models.process_ticket.internet import InternetProcess
 from otrs_somconnexio.otrs_models.process_ticket.mobile import MobileProcessTicket
 from otrs_somconnexio.otrs_models.coverage_ticket import CoverageTicket
 from otrs_somconnexio.otrs_models.service import Service
-
-from otrs_somconnexio.exceptions import TicketNotCreated, ErrorCreatingSession, TicketNotFoundError, \
-    OTRSIntegrationUnknownError
+from otrs_somconnexio.exceptions import TicketNotCreated, ErrorCreatingSession, TicketNotFoundError
 
 
 class OTRSClient():
@@ -102,12 +100,7 @@ class OTRSClient():
 
         Return a PyOTRS Ticket object.
         """
-        try:
-            ticket = self.client.ticket_get_by_id(ticket_id, dynamic_fields=True)
-        except APIError as error:
-            raise TicketNotFoundError(error.message)
-        except Exception as error:
-            raise OTRSIntegrationUnknownError(error.message)
+        ticket = self.client.ticket_get_by_id(ticket_id, dynamic_fields=True)
         if not ticket:
             raise TicketNotFoundError(ticket_id)
         return self._process_ticket_response(ticket)
@@ -137,8 +130,12 @@ class OTRSClient():
         )
         return [CoverageTicket(t) for t in tickets]
 
-    def update_ticket(self, ticket_id, article):
-        self.client.ticket_update(ticket_id, article)
+    def update_ticket(self, ticket_id, article, dynamic_fields=[]):
+        self.client.ticket_update(
+            ticket_id,
+            article,
+            dynamic_fields=dynamic_fields
+        )
 
     def _process_ticket_response(self, ticket):
         service = Service(ticket)
