@@ -6,7 +6,7 @@ from otrs_somconnexio.otrs_models.internet_dynamic_fields import InternetDynamic
 
 class FiberDynamicFields(InternetDynamicFields):
 
-    def _build_specific_dynamic_fields(self):
+    def _build_specific_broadband_service_dynamic_fields(self):
         """ Return list of OTRS DynamicFields to create a OTRS Process Ticket from Eticom Contract.
         Return only the specifics fields of Fiber Ticket. """
         return [
@@ -16,4 +16,5 @@ class FiberDynamicFields(InternetDynamicFields):
     def _df_speed(self):
         return DynamicField(
             name="velocitatSollicitada",
-            value=self.eticom_contract.internet_speed)
+            value=self.service_data.internet_speed
+        )
