@@ -42,10 +42,9 @@ class UpdateTicketWithCoverageTicketInfoTestCase(unittest.TestCase):
 
         UpdateProcessTicketWithCoverageTicketsInfoService(ticket_id, [coverage_ticket]).run()
 
-        MockClient.return_value.ticket_update.assert_called_with(ticket_id, coverage_article)
+        MockClient.return_value.ticket_update.assert_called_with(ticket_id, coverage_article, dynamic_fields=[])
         MockArticle.assert_called_with({
             "Subject": "Sol·licitud cobertura",
             "Body": "tipusVia: foo\nnomVia: foo\nnumero: foo\nbloc: foo\nportal: foo\npis: foo\nescala: foo\nporta: foo\npoblacioServei: foo\nprovinciaServei: foo\nCPservei: foo\naltresCobertura: foo\ncoberturaADSL: foo\ncoberturaFibraMM: foo\ncoberturaFibraVdf: foo\nIDhogar: foo\n",  # noqa
-            "ContentType": "text/plain; charset=utf8",
-            "DynamicField": ""
+            "ContentType": "text/plain; charset=utf8"
         })
