@@ -2,8 +2,6 @@ import unittest
 from mock import Mock
 
 from otrs_somconnexio.otrs_models.adsl_dynamic_fields import ADSLDynamicFields
-from otrs_somconnexio.ticket_exceptions import CustomerVatNumberMissing
-
 
 def dynamic_fields_to_dct(dynamic_fields):
     """
@@ -19,41 +17,40 @@ def dynamic_fields_to_dct(dynamic_fields):
 
 class ADSLDynamicFieldsTestCase(unittest.TestCase):
     def setUp(self):
-        self.party = Mock(spec=[
-            "first_name",
-            "name",
-            "get_identifier",
-            "get_contact_phone",
-            "get_contact_email",
-            "party_type"
+        self.customer_data = Mock(spec=[
+            'first_name',
+            'name',
+            'vat_number',
+            'phone',
+            'email',
         ])
-        self.eticom_contract = Mock(spec=[
-            "id",
-            "party",
-            "bank_iban_service",
-            "internet_now",
-            "internet_telecom_company",
-            "internet_phone",
-            "internet_phone_now",
-            "internet_phone_minutes",
-            "internet_phone_number",
-            "internet_street",
-            "internet_city",
-            "internet_zip",
-            "internet_subdivision",
-            "internet_country",
-            "internet_delivery_street",
-            "internet_delivery_city",
-            "internet_delivery_zip",
-            "internet_delivery_subdivision",
-            "internet_delivery_country",
-            "internet_vat_number",
-            "internet_name",
-            "internet_surname",
-            "internet_lastname",
-            "notes",
-            "coverage_availability",
-            "change_address",
+        self.service_data = Mock(spec=[
+            'order_id',
+            'iban',
+            'phone_number',
+            'landline_type',
+            'landline_minutes',
+            'landline_phone_number',
+            'service_address',
+            'service_city',
+            'service_zip',
+            'service_subdivision',
+            'shipment_address',
+            'shipment_city',
+            'shipment_zip',
+            'shipment_subdivision',
+            'previous_service',
+            'previous_provider',
+            'previous_owner_vat',
+            'previous_owner_name',
+            'previous_owner_surname',
+            'notes',
+            'adsl_coverage',
+            'mm_fiber_coverage',
+            'vdf_fiber_coverage',
+            'change_address',
+            'product',
+            'previous_internal_provider',
         ])
 
         self.adsl_otrs_process_id = "ADSLProcessID"
@@ -61,7 +58,8 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
 
     def test_process_id_field(self):
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -71,7 +69,8 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
 
     def test_activity_id_field(self):
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -81,22 +80,21 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
 
     def test_contract_id_field(self):
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["IDContracte"], self.eticom_contract.id)
+        self.assertEqual(dynamic_fields_dct["IDContracte"], self.service_data.order_id)
 
-    def test_name_field_person_type(self):
-        self.party.first_name = "First Name"
-        self.party.party_type = "person"
-
-        self.eticom_contract.party = self.party
+    def test_first_name_field(self):
+        self.customer_data.first_name = "First Name"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -105,28 +103,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["nomSoci"], "First Name")
 
     def test_name_field_organization_type(self):
-        self.party.name = "First Name"
-        self.party.party_type = "organization"
-
-        self.eticom_contract.party = self.party
+        self.customer_data.name = "Surname"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["nomSoci"], "First Name")
-
-    def test_surname_field_organization_type(self):
-        self.party.name = "Surname"
-        self.party.party_type = "person"
-
-        self.eticom_contract.party = self.party
-
-        dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -135,14 +116,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["cognom1"], "Surname")
 
     def test_vat_number_field(self):
-        mock_vat = Mock(spec=["code"])
-        mock_vat.code = "NIFCode"
-        self.party.get_identifier.return_value = mock_vat
-
-        self.eticom_contract.party = self.party
+        self.customer_data.vat_number = "NIFCode"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -150,23 +128,12 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["NIFNIESoci"], "NIFCode")
 
-    def test_vat_number_field_raise_CustomerVatNumberMissing(self):
-        self.party.get_identifier.return_value = None
-
-        self.eticom_contract.party = self.party
-
-        with self.assertRaises(CustomerVatNumberMissing):
-            ADSLDynamicFields(
-                self.eticom_contract,
-                self.adsl_otrs_process_id,
-                self.adsl_otrs_activity_id
-            ).all()
-
     def test_IBAN_field(self):
-        self.eticom_contract.bank_iban_service = "ES6621000418401234567891"
+        self.service_data.iban = "ES6621000418401234567891"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -175,14 +142,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["IBAN"], "ES6621000418401234567891")
 
     def test_contact_phone_field(self):
-        mock_phone = Mock(spec=["value"])
-        mock_phone.value = "666666666"
-        self.party.get_contact_phone.return_value = mock_phone
-
-        self.eticom_contract.party = self.party
+        self.customer_data.phone = "666666666"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -191,14 +155,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["telefonContacte"], "666666666")
 
     def test_contact_email_field(self):
-        mock_email = Mock(spec=["value"])
-        mock_email.value = "test@email.org"
-        self.party.get_contact_email.return_value = mock_email
-
-        self.eticom_contract.party = self.party
+        self.customer_data.email = "test@email.org"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -206,11 +167,12 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["correuElectronic"], "test@email.org")
 
-    def test_previous_service_adsl_field(self):
-        self.eticom_contract.internet_now = "adsl"
+    def test_previous_service_field(self):
+        self.service_data.previous_service = "ADSL"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -218,49 +180,13 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["serveiPrevi"], "ADSL")
 
-    def test_previous_service_fiber_field(self):
-        self.eticom_contract.internet_now = "fibre"
+    def test_previous_provider_field(self):
+        self.service_data.previous_provider = "Nubip"
+        self.service_data.change_address = False
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["serveiPrevi"], "Fibra")
-
-    def test_none_previous_provider_field(self):
-        self.eticom_contract.internet_telecom_company = None
-
-        dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["proveidorPrevi"], "None")
-
-    def test_other_previous_provider_field(self):
-        self.eticom_contract.internet_telecom_company = Mock(spec=[])
-        self.eticom_contract.internet_telecom_company.name = "NewProvider"
-
-        dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["proveidorPrevi"], "Other")
-
-    def test_mapped_previous_provider_field(self):
-        self.eticom_contract.internet_telecom_company = Mock(spec=[])
-        self.eticom_contract.internet_telecom_company.name = "Aire / Nubip"
-
-        dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -268,11 +194,13 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["proveidorPrevi"], "Nubip")
 
-    def test_landline_number_field(self):
-        self.eticom_contract.internet_phone_now = "666666666"
+    # TODO: Are we using this field??
+    def test_old_landline_number_field(self):
+        self.service_data.phone_number = "666666666"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -280,11 +208,12 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["telefonFixVell"], "666666666")
 
-    def test_address_field(self):
-        self.eticom_contract.internet_street = "Street"
+    def test_service_address_field(self):
+        self.service_data.service_address = "Street"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -292,11 +221,12 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["direccioServei"], "Street")
 
-    def test_city_field(self):
-        self.eticom_contract.internet_city = "City"
+    def test_service_city_field(self):
+        self.service_data.service_city = "City"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -304,11 +234,12 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["poblacioServei"], "City")
 
-    def test_zip_field(self):
-        self.eticom_contract.internet_zip = "000000"
+    def test_service_zip_field(self):
+        self.service_data.service_zip = "000000"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -316,12 +247,12 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["CPservei"], "000000")
 
-    def test_subdivision_field(self):
-        self.eticom_contract.internet_subdivision = Mock(spec=[])
-        self.eticom_contract.internet_subdivision.name = "Subdivision"
+    def test_service_subdivision_field(self):
+        self.service_data.service_subdivision = "Subdivision"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -329,11 +260,12 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["provinciaServei"], "Subdivision")
 
-    def test_delivery_address_field(self):
-        self.eticom_contract.internet_delivery_street = "Street"
+    def test_shipment_address_field(self):
+        self.service_data.shipment_address = "Street"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -341,11 +273,12 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["direccioEnviament"], "Street")
 
-    def test_delivery_city_field(self):
-        self.eticom_contract.internet_delivery_city = "City"
+    def test_shipment_city_field(self):
+        self.service_data.shipment_city = "City"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -353,11 +286,12 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["poblacioEnviament"], "City")
 
-    def test_delivery_zip_field(self):
-        self.eticom_contract.internet_delivery_zip = "000000"
+    def test_shipment_zip_field(self):
+        self.service_data.shipment_zip = "000000"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -365,12 +299,12 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["CPenviament"], "000000")
 
-    def test_delivery_subdivision_field(self):
-        self.eticom_contract.internet_delivery_subdivision = Mock(spec=[])
-        self.eticom_contract.internet_delivery_subdivision.name = "Subdivision"
+    def test_shipment_subdivision_field(self):
+        self.service_data.shipment_subdivision = "Subdivision"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -378,11 +312,12 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["provinciaEnviament"], "Subdivision")
 
-    def test_owner_vat_number_field(self):
-        self.eticom_contract.internet_vat_number = "12345M"
+    def test_owner_vat_field(self):
+        self.service_data.previous_owner_vat = "12345M"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -391,37 +326,37 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["NIFNIEtitular"], "12345M")
 
     def test_owner_name_field(self):
-        self.eticom_contract.internet_name = "Name"
-        self.eticom_contract.internet_surname = "Surname"
-        self.eticom_contract.internet_lastname = "Lastname"
+        self.service_data.previous_owner_name = "Name"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["titular"], "Name Surname Lastname")
+        self.assertEqual(dynamic_fields_dct["titular"], "Name")
 
     def test_owner_surname_field(self):
-        self.eticom_contract.internet_surname = "Surname"
-        self.eticom_contract.internet_lastname = "Lastname"
+        self.service_data.previous_owner_surname = "Surname"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["cognom1Titular"], "Surname Lastname")
+        self.assertEqual(dynamic_fields_dct["cognom1Titular"], "Surname")
 
     def test_notes_field(self):
-        self.eticom_contract.notes = "Note"
+        self.service_data.notes = "Note"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -430,15 +365,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["notes"], "Note")
 
     def test_adsl_coverage_field(self):
-        self.eticom_contract.coverage_availability = Mock(spec=[
-            "adsl",
-            "mm_fiber",
-            "vdf_fiber"
-        ])
-        self.eticom_contract.coverage_availability.adsl = "20"
+        self.service_data.adsl_coverage = "20"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -447,15 +378,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["coberturaADSL"], "20")
 
     def test_mm_fiber_coverage_field(self):
-        self.eticom_contract.coverage_availability = Mock(spec=[
-            "adsl",
-            "mm_fiber",
-            "vdf_fiber"
-        ])
-        self.eticom_contract.coverage_availability.mm_fiber = "CoberturaMM"
+        self.service_data.mm_fiber_coverage = "CoberturaMM"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -464,15 +391,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["coberturaFibraMM"], "CoberturaMM")
 
     def test_vdf_fiber_coverage_field(self):
-        self.eticom_contract.coverage_availability = Mock(spec=[
-            "adsl",
-            "mm_fiber",
-            "vdf_fiber"
-        ])
-        self.eticom_contract.coverage_availability.vdf_fiber = "FibraVdf"
+        self.service_data.vdf_fiber_coverage = "FibraVdf"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -481,10 +404,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["coberturaFibraVdf"], "FibraVdf")
 
     def test_change_address_field(self):
-        self.eticom_contract.change_address = True
+        self.service_data.change_address = "yes"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -492,25 +416,14 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "yes")
 
-    def test_change_address_field_doent_set(self):
-        self.eticom_contract.change_address = False
-
-        dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertNotIn("canviUbicacioMateixTitular", dynamic_fields_dct.keys())
-
 # Service Dynamic Fields
 
     def test_landline_field(self):
-        self.eticom_contract.internet_phone = "phone"
+        self.service_data.landline_type = "phone"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -519,10 +432,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["serveiFix"], "phone")
 
     def test_landline_minutes_field(self):
-        self.eticom_contract.internet_phone_minutes = "100"
+        self.service_data.landline_minutes = "100"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -530,27 +444,54 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["minutsInclosos"], "100")
 
-    def test_keep_landline_number_dont_apply_field(self):
-        self.eticom_contract.internet_phone = "no_phone"
+    def test_landline_number_field(self):
+        self.service_data.landline_phone_number = "666666666"
 
         dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["mantenirFix"], "dont_apply")
-
-    def test_keep_landline_number_field(self):
-        self.eticom_contract.internet_phone = "phone"
-        self.eticom_contract.internet_phone_number = "666666666"
-
-        dynamic_fields = ADSLDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["mantenirFix"], "666666666")
+
+    def test_product_field(self):
+        self.service_data.product = "ADSL20+100"
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["product"], "ADSL20+100")
+
+    def test_previous_provider_CU_field(self):
+        self.service_data.previous_internal_provider = "SC-MM"
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["proveidorPreviCU"], "SC-MM")
+
+    def test_previous_provider_not_exists_in_change_address(self):
+        self.service_data.change_address = True
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertNotIn("proveidorPrevi", dynamic_fields_dct.keys())
