@@ -2,7 +2,6 @@ import unittest
 from mock import Mock
 
 from otrs_somconnexio.otrs_models.fiber_dynamic_fields import FiberDynamicFields
-from otrs_somconnexio.ticket_exceptions import CustomerVatNumberMissing
 
 
 def dynamic_fields_to_dct(dynamic_fields):
@@ -19,42 +18,38 @@ def dynamic_fields_to_dct(dynamic_fields):
 
 class FiberDynamicFieldsTestCase(unittest.TestCase):
     def setUp(self):
-        self.party = Mock(spec=[
-            "first_name",
-            "name",
-            "get_identifier",
-            "get_contact_phone",
-            "get_contact_email",
-            "party_type"
+        self.customer_data = Mock(spec=[
+            'first_name',
+            'name',
+            'vat_number',
+            'phone',
+            'email',
         ])
-        self.eticom_contract = Mock(spec=[
-            "id",
-            "party",
-            "bank_iban_service",
-            "internet_now",
-            "internet_telecom_company",
-            "internet_phone",
-            "internet_phone_now",
-            "internet_phone_minutes",
-            "internet_phone_number",
-            "internet_street",
-            "internet_city",
-            "internet_zip",
-            "internet_subdivision",
-            "internet_country",
-            "internet_delivery_street",
-            "internet_delivery_city",
-            "internet_delivery_zip",
-            "internet_delivery_subdivision",
-            "internet_delivery_country",
-            "internet_vat_number",
-            "internet_name",
-            "internet_surname",
-            "internet_lastname",
-            "notes",
-            "internet_speed",
-            "coverage_availability",
-            "change_address",
+        self.service_data = Mock(spec=[
+            'order_id',
+            'iban',
+            'phone_number',
+            'internet_speed',
+            'service_address',
+            'service_city',
+            'service_zip',
+            'service_subdivision',
+            'shipment_address',
+            'shipment_city',
+            'shipment_zip',
+            'shipment_subdivision',
+            'previous_service',
+            'previous_provider',
+            'previous_owner_vat',
+            'previous_owner_name',
+            'previous_owner_surname',
+            'notes',
+            'adsl_coverage',
+            'mm_fiber_coverage',
+            'vdf_fiber_coverage',
+            'change_address',
+            'product',
+            'previous_internal_provider',
         ])
 
         self.adsl_otrs_process_id = "ADSLProcessID"
@@ -62,7 +57,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
 
     def test_process_id_field(self):
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -72,7 +68,8 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
 
     def test_activity_id_field(self):
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -80,24 +77,24 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["ProcessManagementActivityID"], "ADSLActivityID")
 
+    # TODO: Are we using this field?????
     def test_contract_id_field(self):
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["IDContracte"], self.eticom_contract.id)
+        self.assertEqual(dynamic_fields_dct["IDContracte"], self.service_data.order_id)
 
-    def test_name_field_person_type(self):
-        self.party.first_name = "First Name"
-        self.party.party_type = "person"
-
-        self.eticom_contract.party = self.party
+    def test_first_name_field(self):
+        self.customer_data.first_name = "First Name"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -105,29 +102,12 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["nomSoci"], "First Name")
 
-    def test_name_field_organization_type(self):
-        self.party.name = "First Name"
-        self.party.party_type = "organization"
-
-        self.eticom_contract.party = self.party
+    def test_name_field(self):
+        self.customer_data.name = "Surname"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["nomSoci"], "First Name")
-
-    def test_surname_field_organization_type(self):
-        self.party.name = "Surname"
-        self.party.party_type = "person"
-
-        self.eticom_contract.party = self.party
-
-        dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -136,14 +116,11 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["cognom1"], "Surname")
 
     def test_vat_number_field(self):
-        mock_vat = Mock(spec=["code"])
-        mock_vat.code = "NIFCode"
-        self.party.get_identifier.return_value = mock_vat
-
-        self.eticom_contract.party = self.party
+        self.customer_data.vat_number = "NIFCode"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -151,23 +128,12 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["NIFNIESoci"], "NIFCode")
 
-    def test_vat_number_field_raise_CustomerVatNumberMissing(self):
-        self.party.get_identifier.return_value = None
-
-        self.eticom_contract.party = self.party
-
-        with self.assertRaises(CustomerVatNumberMissing):
-            FiberDynamicFields(
-                self.eticom_contract,
-                self.adsl_otrs_process_id,
-                self.adsl_otrs_activity_id
-            ).all()
-
     def test_IBAN_field(self):
-        self.eticom_contract.bank_iban_service = "ES6621000418401234567891"
+        self.service_data.iban = "ES6621000418401234567891"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -176,14 +142,11 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["IBAN"], "ES6621000418401234567891")
 
     def test_contact_phone_field(self):
-        mock_phone = Mock(spec=["value"])
-        mock_phone.value = "666666666"
-        self.party.get_contact_phone.return_value = mock_phone
-
-        self.eticom_contract.party = self.party
+        self.customer_data.phone = "666666666"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -192,14 +155,11 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["telefonContacte"], "666666666")
 
     def test_contact_email_field(self):
-        mock_email = Mock(spec=["value"])
-        mock_email.value = "test@email.org"
-        self.party.get_contact_email.return_value = mock_email
-
-        self.eticom_contract.party = self.party
+        self.customer_data.email = "test@email.org"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -207,11 +167,12 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["correuElectronic"], "test@email.org")
 
-    def test_previous_service_adsl_field(self):
-        self.eticom_contract.internet_now = "adsl"
+    def test_previous_service_field(self):
+        self.service_data.previous_service = "ADSL"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -219,61 +180,26 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["serveiPrevi"], "ADSL")
 
-    def test_previous_service_fiber_field(self):
-        self.eticom_contract.internet_now = "fibre"
+    def test_previous_provider_field(self):
+        self.service_data.previous_provider = "SomConnexio"
+        self.service_data.change_address = False
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["serveiPrevi"], "Fibra")
-
-    def test_none_previous_provider_field(self):
-        self.eticom_contract.internet_telecom_company = None
-
-        dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["proveidorPrevi"], "None")
-
-    def test_other_previous_provider_field(self):
-        self.eticom_contract.internet_telecom_company = Mock(spec=[])
-        self.eticom_contract.internet_telecom_company.name = "NewProvider"
-
-        dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["proveidorPrevi"], "Other")
-
-    def test_mapped_previous_provider_field(self):
-        self.eticom_contract.internet_telecom_company = Mock(spec=[])
-        self.eticom_contract.internet_telecom_company.name = "Aire / Nubip"
-
-        dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["proveidorPrevi"], "Nubip")
+        self.assertEqual(dynamic_fields_dct["proveidorPrevi"], "SomConnexio")
 
     def test_landline_number_field(self):
-        self.eticom_contract.internet_phone_now = "666666666"
+        self.service_data.phone_number = "666666666"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -282,10 +208,11 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["telefonFixVell"], "666666666")
 
     def test_address_field(self):
-        self.eticom_contract.internet_street = "Street"
+        self.service_data.service_address = "Street"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -294,10 +221,11 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["direccioServei"], "Street")
 
     def test_city_field(self):
-        self.eticom_contract.internet_city = "City"
+        self.service_data.service_city = "City"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -306,10 +234,11 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["poblacioServei"], "City")
 
     def test_zip_field(self):
-        self.eticom_contract.internet_zip = "000000"
+        self.service_data.service_zip = "000000"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -318,11 +247,11 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["CPservei"], "000000")
 
     def test_subdivision_field(self):
-        self.eticom_contract.internet_subdivision = Mock(spec=[])
-        self.eticom_contract.internet_subdivision.name = "Subdivision"
+        self.service_data.service_subdivision = "Subdivision"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -330,11 +259,12 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["provinciaServei"], "Subdivision")
 
-    def test_delivery_address_field(self):
-        self.eticom_contract.internet_delivery_street = "Street"
+    def test_shipment_address_field(self):
+        self.service_data.shipment_address = "Street"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -342,11 +272,12 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["direccioEnviament"], "Street")
 
-    def test_delivery_city_field(self):
-        self.eticom_contract.internet_delivery_city = "City"
+    def test_shipment_city_field(self):
+        self.service_data.shipment_city = "City"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -354,11 +285,12 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["poblacioEnviament"], "City")
 
-    def test_delivery_zip_field(self):
-        self.eticom_contract.internet_delivery_zip = "000000"
+    def test_shipment_zip_field(self):
+        self.service_data.shipment_zip = "000000"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -366,12 +298,12 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["CPenviament"], "000000")
 
-    def test_delivery_subdivision_field(self):
-        self.eticom_contract.internet_delivery_subdivision = Mock(spec=[])
-        self.eticom_contract.internet_delivery_subdivision.name = "Subdivision"
+    def test_shipment_subdivision_field(self):
+        self.service_data.shipment_subdivision = "Subdivision"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -379,11 +311,12 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["provinciaEnviament"], "Subdivision")
 
-    def test_owner_vat_number_field(self):
-        self.eticom_contract.internet_vat_number = "12345M"
+    def test_owner_vat_field(self):
+        self.service_data.previous_owner_vat = "12345M"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -392,37 +325,37 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["NIFNIEtitular"], "12345M")
 
     def test_owner_name_field(self):
-        self.eticom_contract.internet_name = "Name"
-        self.eticom_contract.internet_surname = "Surname"
-        self.eticom_contract.internet_lastname = "Lastname"
+        self.service_data.previous_owner_name = "Name"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["titular"], "Name Surname Lastname")
+        self.assertEqual(dynamic_fields_dct["titular"], "Name")
 
     def test_owner_surname_field(self):
-        self.eticom_contract.internet_surname = "Surname"
-        self.eticom_contract.internet_lastname = "Lastname"
+        self.service_data.previous_owner_surname = "Surname"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["cognom1Titular"], "Surname Lastname")
+        self.assertEqual(dynamic_fields_dct["cognom1Titular"], "Surname")
 
     def test_notes_field(self):
-        self.eticom_contract.notes = "Note"
+        self.service_data.notes = "Note"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -431,15 +364,11 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["notes"], "Note")
 
     def test_adsl_coverage_field(self):
-        self.eticom_contract.coverage_availability = Mock(spec=[
-            "adsl",
-            "mm_fiber",
-            "vdf_fiber"
-        ])
-        self.eticom_contract.coverage_availability.adsl = "20"
+        self.service_data.adsl_coverage = "20"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -448,15 +377,11 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["coberturaADSL"], "20")
 
     def test_mm_fiber_coverage_field(self):
-        self.eticom_contract.coverage_availability = Mock(spec=[
-            "adsl",
-            "mm_fiber",
-            "vdf_fiber"
-        ])
-        self.eticom_contract.coverage_availability.mm_fiber = "CoberturaMM"
+        self.service_data.mm_fiber_coverage = "CoberturaMM"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -465,15 +390,11 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["coberturaFibraMM"], "CoberturaMM")
 
     def test_vdf_fiber_coverage_field(self):
-        self.eticom_contract.coverage_availability = Mock(spec=[
-            "adsl",
-            "mm_fiber",
-            "vdf_fiber"
-        ])
-        self.eticom_contract.coverage_availability.vdf_fiber = "FibraVdf"
+        self.service_data.vdf_fiber_coverage = "FibraVdf"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -482,10 +403,11 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["coberturaFibraVdf"], "FibraVdf")
 
     def test_change_address_field(self):
-        self.eticom_contract.change_address = True
+        self.service_data.change_address = "yes"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
@@ -494,27 +416,68 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "yes")
 
     def test_change_address_field_doent_set(self):
-        self.eticom_contract.change_address = False
+        self.service_data.change_address = "no"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertNotIn("canviUbicacioMateixTitular", dynamic_fields_dct.keys())
+        self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "no")
 
 # Service Dynamic Fields
 
     def test_speed_field(self):
-        self.eticom_contract.internet_speed = "120MB"
+        self.service_data.internet_speed = "120MB"
 
         dynamic_fields = FiberDynamicFields(
-            self.eticom_contract,
+            self.service_data,
+            self.customer_data,
             self.adsl_otrs_process_id,
             self.adsl_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["velocitatSollicitada"], "120MB")
+
+    def test_product_field(self):
+        self.service_data.product = "FIBRA100"
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["product"], "FIBRA100")
+
+    def test_previous_provider_CU_field(self):
+        self.service_data.previous_internal_provider = "SC-MM"
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["proveidorPreviCU"], "SC-MM")
+
+    def test_previous_provider_not_exists_in_change_address(self):
+        self.service_data.change_address = True
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertNotIn("proveidorPrevi", dynamic_fields_dct.keys())
