@@ -2,7 +2,6 @@ import unittest
 from mock import Mock
 
 from otrs_somconnexio.otrs_models.mobile_dynamic_fields import MobileDynamicFields
-from otrs_somconnexio.ticket_exceptions import CustomerVatNumberMissing
 
 
 def dynamic_fields_to_dct(dynamic_fields):
@@ -19,34 +18,44 @@ def dynamic_fields_to_dct(dynamic_fields):
 
 class MobileDynamicFieldsTestCase(unittest.TestCase):
     def setUp(self):
-        self.party = Mock(spec=[
-            'first_name',
-            'name',
-            'get_identifier',
-            'get_contact_email',
-            'get_contact_phone'
-        ])
-        self.eticom_contract = Mock(spec=[
+        self.customer_data = Mock(spec=[
             'id',
-            'party',
-            'bank_iban_service',
-            'mobile_phone_number',
-            'mobile_sc_icc',
-            'mobile_icc_number',
-            'mobile_min',
-            'mobile_internet',
-            'mobile_option',
-            'mobile_telecom_company',
+            'vat_number',
+            'email',
+            'phone',
+            'name',
+            'first_name',
+            'street',
+            'zip',
+            'city',
+            'subdivision',
         ])
-        self.eticom_contract.mobile_option = 'new'
-        self.eticom_contract.mobile_min = '0'
+        self.mobile_data = Mock(spec=[
+            'order_id',
+            'phone_number',
+            'iban',
+            'sc_icc',
+            'icc',
+            'service_minutes',
+            'service_internet',
+            'service_internet_unlimited',
+            'portability',
+            'previous_owner_vat',
+            'previous_owner_name',
+            'previous_owner_surname',
+            'previous_provider',
+            'product'
+        ])
+        self.mobile_data.portability = False
+        self.mobile_data.service_minutes = '0'
 
         self.mobile_otrs_process_id = "MobileProcessID"
         self.mobile_otrs_activity_id = "MobileActivityID"
 
     def test_process_id_field(self):
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -56,7 +65,8 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
 
     def test_activity_id_field(self):
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -65,12 +75,11 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["ProcessManagementActivityID"], "MobileActivityID")
 
     def test_first_name_field(self):
-        self.party.first_name = 'First Name'
-
-        self.eticom_contract.party = self.party
+        self.customer_data.first_name = 'First Name'
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -79,12 +88,11 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["nomSoci"], "First Name")
 
     def test_name_field(self):
-        self.party.name = 'Name'
-
-        self.eticom_contract.party = self.party
+        self.customer_data.name = 'Name'
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -93,14 +101,11 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["cognom1"], "Name")
 
     def test_vat_number_field(self):
-        mock_vat = Mock(spec=['code'])
-        mock_vat.code = 'NIFCode'
-        self.party.get_identifier.return_value = mock_vat
-
-        self.eticom_contract.party = self.party
+        self.customer_data.vat_number = 'NIFCode'
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -108,23 +113,12 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["NIFNIESoci"], "NIFCode")
 
-    def test_vat_number_field_raise_CustomerVatNumberMissing(self):
-        self.party.get_identifier.return_value = None
-
-        self.eticom_contract.party = self.party
-
-        with self.assertRaises(CustomerVatNumberMissing):
-            MobileDynamicFields(
-                self.eticom_contract,
-                self.mobile_otrs_process_id,
-                self.mobile_otrs_activity_id
-            ).all()
-
     def test_line_field(self):
-        self.eticom_contract.mobile_phone_number = '666666666'
+        self.mobile_data.phone_number = '666666666'
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -133,10 +127,11 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["liniaMobil"], "666666666")
 
     def test_icc_sc_field(self):
-        self.eticom_contract.mobile_sc_icc = '1234'
+        self.mobile_data.sc_icc = '1234'
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -145,10 +140,11 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["ICCSC"], "1234")
 
     def test_icc_donor_field(self):
-        self.eticom_contract.mobile_icc_number = '4321'
+        self.mobile_data.icc = '4321'
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -156,11 +152,12 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["ICCdonant"], "4321")
 
-    def test_minutes_field_0min(self):
-        self.eticom_contract.mobile_min = '0'
+    def test_minutes_field(self):
+        self.mobile_data.service_minutes = '0min'
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -168,47 +165,12 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["minutsMobil"], "0min")
 
-    def test_minutes_field_100min(self):
-        self.eticom_contract.mobile_min = '100'
-
-        dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
-            self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["minutsMobil"], "100min")
-
-    def test_minutes_field_200min(self):
-        self.eticom_contract.mobile_min = '200'
-
-        dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
-            self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["minutsMobil"], "200min")
-
-    def test_minutes_field_unlimited(self):
-        self.eticom_contract.mobile_min = 'unlimited'
-
-        dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
-            self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["minutsMobil"], "unlim")
-
     def test_data_field(self):
-        self.eticom_contract.mobile_internet = '5GB'
+        self.mobile_data.service_internet = '5GB'
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -216,24 +178,12 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["dadesMobil"], "5GB")
 
-    def test_data_field_unlimited(self):
-        self.eticom_contract.mobile_internet = None
-        self.eticom_contract.mobile_internet_unlimited = '10GB'
-
-        dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
-            self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["dadesMobil"], "10GB")
-
     def test_service_type_field_new(self):
-        self.eticom_contract.mobile_option = "new"
+        self.mobile_data.portability = False
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -242,10 +192,11 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["tipusServeiMobil"], "altaNova")
 
     def test_service_type_field_portability(self):
-        self.eticom_contract.mobile_option = "portability"
+        self.mobile_data.portability = True
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -254,10 +205,11 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["tipusServeiMobil"], "portabilitat")
 
     def test_IBAN_field(self):
-        self.eticom_contract.bank_iban_service = "ES6621000418401234567891"
+        self.mobile_data.iban = "ES6621000418401234567891"
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -266,14 +218,11 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["IBAN"], "ES6621000418401234567891")
 
     def test_contact_email_field(self):
-        mock_email = Mock(spec=["value"])
-        mock_email.value = "test@email.org"
-        self.party.get_contact_email.return_value = mock_email
-
-        self.eticom_contract.party = self.party
+        self.customer_data.email = "test@email.org"
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -282,14 +231,11 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["correuElectronic"], "test@email.org")
 
     def test_contact_phone_field(self):
-        mock_phone = Mock(spec=["value"])
-        mock_phone.value = "666666666"
-        self.party.get_contact_phone.return_value = mock_phone
-
-        self.eticom_contract.party = self.party
+        self.customer_data.phone = "666666666"
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
@@ -297,40 +243,120 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["telefonContacte"], "666666666")
 
-    def test_none_previous_provider_field(self):
-        self.eticom_contract.mobile_telecom_company = None
+    def test_previous_provider_field(self):
+        self.mobile_data.previous_provider = "AireNubip"
 
         dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
-            self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["operadorDonantMobil"], "None")
-
-    def test_other_previous_provider_field(self):
-        self.eticom_contract.mobile_telecom_company = Mock(spec=[])
-        self.eticom_contract.mobile_telecom_company.name = "NewProvider"
-
-        dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
-            self.mobile_otrs_process_id,
-            self.mobile_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["operadorDonantMobil"], "Other")
-
-    def test_mapped_previous_provider_field(self):
-        self.eticom_contract.mobile_telecom_company = Mock(spec=[])
-        self.eticom_contract.mobile_telecom_company.name = "Aire / Nubip"
-
-        dynamic_fields = MobileDynamicFields(
-            self.eticom_contract,
+            self.mobile_data,
+            self.customer_data,
             self.mobile_otrs_process_id,
             self.mobile_otrs_activity_id
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["operadorDonantMobil"], "AireNubip")
+
+    # Portability
+    def test_previous_owner_vat_portability(self):
+        self.mobile_data.previous_owner_vat = "1234G"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["dniTitularAnterior"], "1234G")
+
+    def test_previous_owner_name_portability(self):
+        self.mobile_data.previous_owner_name = "Josep"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["titular"], "Josep")
+
+    def test_previous_owner_first_name_portability(self):
+        self.mobile_data.previous_owner_surname = "Nadal"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["cognom1Titular"], "Nadal")
+
+    def test_product_field(self):
+        self.mobile_data.product = "SE_SC_MOB_100_100"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["product"], "SE_SC_MOB_100_100")
+
+    def test_street_field(self):
+        self.customer_data.street = "Les Moreres"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["nomVia"], "Les Moreres")
+
+    def test_city_field(self):
+        self.customer_data.city = "Alacant"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["localitat"], "Alacant")
+
+    def test_zip_field(self):
+        self.customer_data.zip = "03140"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["codiPostal"], "03140")
+
+    def test_subdivision_field(self):
+        self.customer_data.subdivision = "ES-A"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["provinciaMobil"], "ES-A")
